==> micropython_1.22.1+ds.orig.tar.xz: micropython-1.22.1/ports/unix/variants/coverage/mpconfigvariant.h <==
/*
 * This file is part of the MicroPython project, http://micropython.org/
 *
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2016 Damien P. George
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

// This config enables almost all possible features such that it can be used
// for coverage testing.

// Set base feature level.
#define MICROPY_CONFIG_ROM_LEVEL (MICROPY_CONFIG_ROM_LEVEL_EVERYTHING)

// Enable extra Unix features.
#include "../mpconfigvariant_common.h"

// Enable testing of split heap.
#define MICROPY_GC_SPLIT_HEAP          (1)
#define MICROPY_GC_SPLIT_HEAP_N_HEAPS  (4)

// Enable additional features.
#define MICROPY_DEBUG_PARSE_RULE_NAME  (1)
#define MICROPY_TRACKED_ALLOC          (1)
#define MICROPY_WARNINGS_CATEGORY      (1)
#define MICROPY_PY_CRYPTOLIB_CTR       (1)

==> micropython_1.26.1+ds.orig.tar.xz: micropython-1.26.1/ports/unix/variants/coverage/mpconfigvariant.h <==
/*
 * This file is part of the MicroPython project, http://micropython.org/
 *
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2016 Damien P. George
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

// This config enables almost all possible features such that it can be used
// for coverage testing.

// Set base feature level.
#define MICROPY_CONFIG_ROM_LEVEL (MICROPY_CONFIG_ROM_LEVEL_EVERYTHING)

// Enable extra Unix features.
#include "../mpconfigvariant_common.h"

// Enable testing of split heap.
#define MICROPY_GC_SPLIT_HEAP          (1)
#define MICROPY_GC_SPLIT_HEAP_N_HEAPS  (4)

// Enable additional features.
#define MICROPY_DEBUG_PARSE_RULE_NAME  (1)
#define MICROPY_PY_SYS_SETTRACE        (1)
#define MICROPY_TRACKED_ALLOC          (1)
#define MICROPY_WARNINGS_CATEGORY      (1)
#undef MICROPY_VFS_ROM_IOCTL
#define MICROPY_VFS_ROM_IOCTL          (1)
#define MICROPY_PY_CRYPTOLIB_CTR       (1)
#define MICROPY_SCHEDULER_STATIC_NODES (1)

// Enable os.uname for attrtuple coverage test
#define MICROPY_PY_OS_UNAME            (1)
#define MICROPY_HW_BOARD_NAME          "a machine"
#define MICROPY_HW_MCU_NAME            MICROPY_PY_SYS_PLATFORM
// Keep the standard banner message
#define MICROPY_BANNER_MACHINE MICROPY_PY_SYS_PLATFORM " [" MICROPY_PLATFORM_COMPILER "] version"
